@@ -4,7 +4,7 @@ use Email::Simple;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '2.12';
+our $VERSION = '2.13';
 use Module::Pluggable search_path => [ __PACKAGE__ ], require => 1;
 
 my @plugins = __PACKAGE__->plugins(); # Requires them.
@@ -19,6 +19,8 @@ sub object {
 sub new {
     my ($class, $foreign) = @_;
 
+    return $foreign if eval { $foreign->isa($class) };
+
     $class = ref($class) || $class;
 
     $foreign = Email::Simple->new($foreign) unless ref $foreign;
@@ -60,6 +62,10 @@ for my $func (qw(get_header get_body set_header set_body as_string)) {
         my $self = shift;
         my ($thing, @args) = $self->_obj_and_args(@_);
 
+        # In the event of Email::Abstract->get_body($email_abstract), convert
+        # it into an object method call.
+        $thing = $thing->object if eval { $thing->isa($self) };
+
         unless (ref $thing) {
             croak "can't alter string in place" if substr($func, 0, 3) eq 'set';
             $thing = Email::Simple->new($thing)
